.. highlight:: shell

============
Installation
============


As a pip package
----------------

You can use a git-based URL in a pip installation:

.. code-block:: console

    $ pip install git+https://github.com/openshine/python-esqb.git#egg=esqb


From sources
------------

The sources for ElasticSearch Query Builder can be downloaded from the `GitHub repo`_.

First, clone the repository:

.. code-block:: console

    $ git clone https://github.com/openshine/python-esqb.git

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ pip install -e .


.. _GitHub repo: https://github.com/openshine/python-esqb
